@@ -54,8 +54,11 @@ heckit2fit <- function( selection, outcome,
       stop( "the dependent variable of 'selection' has to contain",
          " exactly two levels (e.g. FALSE and TRUE)" )
    }
+   ysNames <- names( YS )
    YS <- as.integer(YS == probitLevels[ 2 ])
                                         # selection kept as integer internally
+   names( YS ) <- ysNames
+
    ## Outcome equation
    m <- match(c("outcome", "data", "subset", "weights",
                 "offset"), names(mf), 0)
@@ -81,9 +84,9 @@ heckit2fit <- function( selection, outcome,
    if(print.level > 0) {
       cat(sum(badRow), "invalid observations\n")
    }
-   XS <- XS[!badRow,]
+   XS <- XS[!badRow,,drop=FALSE]
    YS <- YS[!badRow]
-   XO <- XO[!badRow,]
+   XO <- XO[!badRow,,drop=FALSE]
    YO <- YO[!badRow]
    ## Now indices for packing the separate outcomes into full outcome vectors.  Note we treat
    ## invMillsRatio as a separate parameter
